<?php
/**
 * @file
 * Theme code for openpublic document feature.
 */

/**
 * Implements hook_theme().
 */
function openpublic_document_theme($existing) {
  $item = $existing['node'];
  $item['path'] = drupal_get_path('module', 'openpublic_document') . "/theme";
  $item['template'] = 'node--document';
  return array("node__document" => $item);
}

/**
 * Implements hook_preprocess_views_view_field().
 *
 * For document displays, replaces the value of the URI field with the upper-case
 * file extension. This is as opposed to useing the mimetype for anything, since
 * it'll be more specific to the actual file in question.
 */
function openpublic_document_preprocess_views_view_field(&$vars, $hook) {
  if ($vars['view']->name == 'documents' && !empty($vars['field']->field_alias)) {
    if ($vars['field']->field_alias == 'file_managed_file_usage_uri') {
      $vars['field']->last_render = strtoupper(substr($vars['row']->file_managed_file_usage_uri, strpos($vars['row']->file_managed_file_usage_uri, '.') + 1));
    }
  }
}

/**
 * Implmentation of hook_preprocess_node().
 *
 * This adds additional information about the file download after the download link itself.
 */
function openpublic_document_preprocess_node(&$vars) {
  if ($vars['type'] == 'document') {
    drupal_add_css(drupal_get_path('module', 'openpublic_document') . '/theme/node--document.css');

    if (!empty($vars['field_document_attachment'])) {
      foreach ($vars['field_document_attachment'] as $id => $attachment) {
        if (!$attachment['display']) {
          continue;
        }
        $file = $vars['field_document_attachment'][$id];
        $vars['content']['field_document_attachment'][$id]['#prefix'] = '<div class="download-btn">';
        $download = '';
        $download .= '<span class="download-type">';
        $download .= strtoupper(substr($file['filename'], strpos($file['filename'], '.') + 1));
        $download .= '</span>';
        $download .= ': ';
        $download .= '<span class="download-size">';
        $download .= format_size($file['filesize']);
        $download .= '</span>';
        $vars['content']['field_document_attachment'][$id]['#suffix'] = $download;
        $vars['content']['field_document_attachment'][$id]['#suffix'] .= '</div>';
      }
    }
  }
}

/**
 * Implements hook_preprocess_file_link().
 *
 * Changes title of the link to 'Download'.
 */
function openpublic_document_preprocess_file_link(&$vars) {
  $vars['file']->filename = "Download";
}
