<?php
/**
 * @file
 * Code for the OpenPublic profile.
 */

/**
* A trick to enforce page refresh when theme is changed from an overlay.
*/
function openpublic_admin_paths_alter(&$paths) {
  $paths['admin/appearance/default*'] = FALSE;
}


/**
 * Password save validate handler.
 */
function openpublic_password_validate($form, &$form_state) {
  $values = $form_state['values'];
  $account = (object)array('uid' => 1);
  $account->roles = array(DRUPAL_AUTHENTICATED_RID => DRUPAL_AUTHENTICATED_RID);

  if (!empty($values['account']['pass'])) {
    $error = _password_policy_constraint_validate($values['account']['pass'], $account);
    if ($error) {
      form_set_error('pass', t('Your password has not met the following requirement(s):') .'<ul><li>'. implode('</li><li>', $error) .'</li></ul>');
    }
  }
}

/**
 * Password save submit handler.
 */
function openpublic_password_submit($form, &$form_state) {
  global $user;

  $values = $form_state['values'];
  $account = (object)array('uid' => 1);

  // Track the hashed password values which can then be used in the history constraint.
  if ($account->uid && !empty($values['account']['pass'])) {
    _password_policy_store_password($account->uid, $values['account']['pass']);
  }
}

/**
 * Implements hook_appstore_stores_info().
 */
function openpublic_apps_servers_info() {
 $info =  drupal_parse_info_file(dirname(__file__) . '/openpublic.info');
 return array(
   'openpublic' => array(
     'title' => 'OpenPublic',
     'description' => "Apps for the Openpublic distribution",
     'manifest' => 'http://appserver.openpublicapp.com/app/query/openpublic-testing',
     'profile' => 'openpublic',
     'profile_version' => isset($info['version']) ? $info['version'] : '7.x-1.0-beta1',
     'server_name' => !empty($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '',
     'server_ip' => !empty($_SERVER['SERVER_ADDR']) ? $_SERVER['SERVER_ADDR'] : '',
   ),
 );
}

/**
 * Implements hook_init().
 */
function openpublic_init() {
 $cache = cache_get("openpublic_info");
 if (isset($cache->data)) {
   $data = $cache->data;
 }
 else {
   $info =  drupal_parse_info_file(dirname(__file__) . '/openpublic.info');
   $data = array("profile" => "openpublic", "profile_version" => isset($info['version']) ? $info['version'] : '7.x-1.x-dev');
   cache_set("openpublic_info", $data);
 }
 drupal_add_js($data, 'setting');

}

/**
 * Implements hook_install_configure_form_alter().
 */
function openpublic_form_install_configure_form_alter(&$form, &$form_state) {
  $form['site_information']['site_name']['#default_value'] = 'Openpublic';
  $form['site_information']['site_mail']['#default_value'] = 'admin@'. $_SERVER['HTTP_HOST'];
  $form['admin_account']['account']['name']['#default_value'] = 'admin';
  $form['admin_account']['account']['mail']['#default_value'] = 'admin@'. $_SERVER['HTTP_HOST'];
}

/**
 * Implements hook_features_pipe_node_alter().
 */
function openpublic_features_pipe_node_alter(&$more, $data, $export) {
  // Enforces permissions being owned by feature defining them.
  foreach ($data as $node_type) {
    if (node_type_get_type($node_type)) {
      foreach (array_keys(node_list_permissions($node_type)) as $permission) {
        $more['user_permission'][] = $permission;
      }
    }
  }
}

/**
 * Returns the modules that are considered 'demo' modules to parent module.
 *
 * @todo Use apps to get what is considered a demo module.
 */
function openpublic_demo_modules() {
  return array(
    'openpublic_blog_demo' => 'openpublic_blog',
    'openpublic_document_demo' => 'openpublic_document',
    'openpublic_editors_choice_demo' => 'openpublic_editors_choice',
    'openpublic_home_page_feature_demo' => 'openpublic_home_page_feature',
    'openpublic_person_demo' => 'openpublic_person',
    'openpublic_press_release_demo' => 'openpublic_press_release',
    'openpublic_services_demo' => 'openpublic_services',
    'openpublic_site_page_demo' => 'openpublic_site_page',
    'openpublic_webform_demo' => 'openpublic_webform',
  );
}
