<?php
/**
 * @file
 * Themeing functions for openpublic theme.
 */

/**
 * Implements hook_preprocess_node().
 *
 * Turn off number of reads.
 */
function openpublic_theme_preprocess_node(&$variables) {
  unset($variables['content']['links']['statistics']);
}

/**
 * Implements hook_preprocess_page().
 */
function openpublic_theme_preprocess_page(&$variables) {
  global $user;
  global $language;

  $menu_utility = _openpublic_menu_navigation_links('menu-utility');
  if ($user->uid) {
    foreach ($menu_utility as $key => $item) {
      if ($item['href'] == 'user') {
        $menu_utility[$key]['title'] = 'My Account';
      }
    }
  }
  $menu_utility = theme(
    'links',
    array(
      'links' => $menu_utility,
      'attributes' => array(
        'id' => 'user-menu',
        'class' => array('links', 'clearfix'),
      ),
      'heading' => array(
        'text' => t('User menu'),
        'level' => 'h2',
        'class' => array('element-invisible'),
      ),
    )
  );
  $variables['menu_utility'] = $menu_utility;

  $footer_utility = _openpublic_menu_navigation_links('menu-footer-utility');
  $footer_utility = theme(
    'links',
    array(
      'links' => $footer_utility,
      'attributes' => array(
        'id' => 'footer-utility',
        'class' => array('links', 'clearfix'),
      ),
      'heading' => array(
        'text' => t('Utility Links'),
        'level' => 'h2',
        'class' => array('element-invisible'),
      ),
    )
  );
  $variables['footer_utility'] = $footer_utility;

  $footer_menu = menu_tree_output(_openpublic_menu_build_tree('main-menu', array('max_depth' => 2)));
  // Set the active trail
  $active_trail = menu_get_active_trail();
  foreach ($active_trail as $trail) {
    if (isset($trail['mlid']) && isset($footer_menu[$trail['mlid'] ] )) {
      $footer_menu[$trail['mlid']]['#attributes']['class'][] = 'active-trail';
    }
  }
  $variables['footer_menu'] = $footer_menu;
  $variables['main_menu'] = $footer_menu;


  $frontpage = variable_get('site_frontpage', 'node');

  $logo = $variables['logo'];
  $site_name = $variables['site_name'];
  if (preg_match("|^.*/files/(.*)|", $logo, $m)) {
    $file = "public://" . $m[1];
    $header_logo = l(theme('image_style', array('style_name' => 'logo', 'path' => $file, 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
    $footer_logo = l(theme('image_style', array('style_name' => 'logo-small', 'path' => $file, 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
  }
  elseif ($logo == url(drupal_get_path('theme', 'openpublic_theme') . "/logo.png", array('absolute' => TRUE))) {
    $header_logo = l(theme('image', array('path' => $logo, 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
    $footer_logo = l(theme('image', array('path' => drupal_get_path('theme', 'openpublic_theme') . "/logo-sm.png", 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
  }
  else {
    $header_logo = l(theme('image', array('path' => $logo, 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
    $footer_logo = l(theme('image', array('path' => $logo, 'alt' => "$site_name logo")), '', array("html" => TRUE, 'attributes' => array('class' => 'logo')));
  }

  $variables['footer_logo'] = $footer_logo;
  $variables['header_logo'] = $header_logo;
  $variables['front_page'] = $frontpage;
  if (function_exists('defaultcontent_get_node') &&
      ($node = defaultcontent_get_node("email_update")) && node_access('view', $node)) {
    $node = node_view($node);
    $variables['subscribe_form'] = $node['webform'];
  }
}

/**
 * Return the navigation links, translated if enabled.
 */
function _openpublic_menu_navigation_links($menu_name, $level = 0) {
  // check for i18n_menu presence
  if (function_exists('i18n_menu_navigation_links')) {
    return i18n_menu_navigation_links($menu_name, $level);
  }
  else {
    return menu_navigation_links($menu_name, $level);
  }
}

/**
 * Return links for a menu, translated if enabled.
 */
function _openpublic_menu_build_tree($menu_name, $parameters = array()) {
  $tree = menu_build_tree($menu_name, $parameters);
  if (function_exists('i18n_menu_localize_tree')) {
    $tree = i18n_menu_localize_tree($tree);
  }

  return $tree;
}
